<?php
    /**
     * This function is called immediately before the action command of a
     * submitted process activity is started. Here a customer functionality
     * can be implemented, which is called for to do some initialisations
     * before the activity actions are started.
     *
     * The function is called in a context, in which the HWM API functions
     * can be called, so no explicite include of the hwm_api.php is required.
     *
     * The context of the calling process can be requested using the HWM API
     * functions. It can be usefull if different functionality shall be
     * implemented for different processes/activities.
     *
     * The function is called in a context where the HWM database is connected,
     * so it must not connect to the database explicitly again. For eventual
     * table locks and commits has to care the function itself.
     *
     * @param (string) error message which shall be displayed if the function
     * fails.
     * @return (bool) true on success, false otherwise
     */


    require_once('bs_pre_action.php');
    require_once('bs_snow_lib.php');


    function hwm_pre_action(&$error_message)
    {
        if (defined('HWM_REST_API_CONTEXT'))
        {
            // Here the system ID of the SC Ticket, sent in the REST API request
            // from ServiceNow, is saved to the SNOW_ID_<stage> process
            // parameter.
            if (!snow_pre_action())
            {
                $error_message = hwm_get_last_error();
                return false;
            }
        }
        if (!bs_pre_action())
        {
            $error_message = hwm_get_last_error();
            return false;
        }
        $error_message = '';
        return true;
    }
?>
